Commands

Enum Commands 

pub enum Commands {
    Install {
        version: VersionSpec,
        arch: Option<ArchSpec>,
        insecure: bool,
    },
    Uninstall {
        version: VersionSpec,
    },
    List {
        available: bool,
    },
    On,
    Off,
    Root {
        path: Option<String>,
    },
    Arch,
    Proxy {
        url: Option<String>,
    },
    Current,
    NodeMirror {
        url: Option<String>,
    },
    NpmMirror {
        url: Option<String>,
    },
    Use {
        version: VersionSpec,
        arch: Option<ArchSpec>,
    },
}

Variants



Install

The version can be a specific version, “latest” for the latest current version, or “lts” for the most recent LTS version. Optionally specify whether to install the 32 or 64 bit version (defaults to system arch). Set [arch] to “all” to install 32 AND 64 bit versions. Add –insecure to the end of this command to bypass SSL validation of the remote download server.

Fields

version: VersionSpec

The version can be a specific version, “latest” for the latest current version, or “lts” for the most recent LTS version. [possible values: (eg: 1.1.0), lts, latest]

arch: Option<ArchSpec>

Specify whether to install the 32 or 64 bit version (defaults to system arch).

insecure: bool

Pass SSL validation of the remote download server.



Uninstall

The version must be a specific version.

Fields

version: VersionSpec

The version to uninstall.



List

List the node.js installations.

Fields

available: bool

Show online available versions.



On

Enable node.js version management.



Off

Disable node.js version management.



Root

Set the directory where nvm should store different versions of node.js. If is not set, the current root will be displayed.

Fields

path: Option<String>

The path to set as the root directory.



Arch

Show if node is running in 32 or 64 bit mode.



Proxy

Set a proxy to use for downloads.

Fields

url: Option<String>

Leave url blank to see the current proxy. Set url to “none” to remove the proxy.



Current

Display active version.



NodeMirror

Set the node mirror. Defaults to https://nodejs.org/dist/. Leave url blank to use default url.

Fields

url: Option<String>

The node mirror to use. Leave url blank to use default url.



NpmMirror

Set the npm mirror. Defaults to https://github.com/npm/cli/archive/. Leave url blank to use default url.

Fields

url: Option<String>

The npm mirror to use. Leave url blank to use default url.



Use

Switch to use the specified version. Optionally use “latest”, “lts”, or “newest”. “newest” is the latest installed version. Optionally specify 32/64bit architecture. nvm use will continue using the selected version, but switch to 32/64 bit mode.

Fields

version: VersionSpec

The version to use.

arch: Option<ArchSpec>

The architecture to use.