pub struct Config {
pub root: Option<PathBuf>,
pub proxy: Option<String>,
pub node_mirror: Option<String>,
pub npm_mirror: Option<String>,
pub arch: Option<ArchSpec>,
pub originalpath: Option<PathBuf>,
pub originalversion: Option<String>,
/* private fields */
}Fields
root: Option<PathBuf>Node.js storage root
proxy: Option<String>Node.js proxy
node_mirror: Option<String>Node.js mirror
npm_mirror: Option<String>npm mirror
arch: Option<ArchSpec>originalpath: Option<PathBuf>originalversion: Option<String>Implementations
Sourceimpl Config
impl Config
Sourcepub fn load() -> Config
pub fn load() -> Config
Load config from file. Returns None if no config file exists.
If both toml and yaml features are enabled, it will try to load from toml first.
If toml is not enabled, it will try to load from yaml.
If yaml is not enabled, it will return None.
pub fn save(&self) -> Result
pub fn is_valid(&self) -> Result