pub enum Commands {
Install {
version: VersionSpec,
arch: Option<ArchSpec>,
insecure: bool,
},
Uninstall {
version: VersionSpec,
},
List {
available: bool,
},
On,
Off,
Root {
path: Option<String>,
},
Arch,
Proxy {
url: Option<String>,
},
Current,
NodeMirror {
url: Option<String>,
},
NpmMirror {
url: Option<String>,
},
Use {
version: VersionSpec,
arch: Option<ArchSpec>,
},
}Variants
Install
The version can be a specific version, “latest” for the latest current version, or “lts” for the most recent LTS version. Optionally specify whether to install the 32 or 64 bit version (defaults to system arch). Set [arch] to “all” to install 32 AND 64 bit versions. Add –insecure to the end of this command to bypass SSL validation of the remote download server.
Fields
version: VersionSpecThe version can be a specific version, “latest” for the latest current version, or “lts” for the
most recent LTS version. [possible values:
Uninstall
The version must be a specific version.
Fields
version: VersionSpecThe version to uninstall.
List
List the node.js installations.
On
Enable node.js version management.
Off
Disable node.js version management.
Root
Set the directory where nvm should store different versions of node.js.
If
Arch
Show if node is running in 32 or 64 bit mode.
Proxy
Set a proxy to use for downloads.
Fields
Current
Display active version.
NodeMirror
Set the node mirror. Defaults to https://nodejs.org/dist/. Leave url blank to use default url.
NpmMirror
Set the npm mirror. Defaults to https://github.com/npm/cli/archive/. Leave url blank to use default url.
Use
Switch to use the specified version. Optionally use “latest”, “lts”, or “newest”.
“newest” is the latest installed version. Optionally specify 32/64bit architecture.
nvm use